#!/bin/sh

# Creates  a directory hierarchy.
# Each leading tab puts the new directory further in the last created directory's hierarchy.
#
# Ex: 
# src
#     main
#         java
#             com/company/app
#                 dao
#                 model
#     test
#         java
#             com/company/app
# 
# Usage 1 : mktree.sh < file , the file must be in the format described above
# Usage 2 : mktree.sh , then enter the directory names sequentially in the console


# Save the current delimiter, then set it to "\n" (new line)
OLDIFS=$IFS
IFS=$'\n'

# The stack used to keep the directory structure
declare -a STACK

# Read the input file or prompt. For each line...
while read DIRNAME; do 

	# Count the number of leading tabs 
	NBTABS=`expr match "$DIRNAME" '\s*'`; 			
	
	# Put the directory name on the stack
	STACK[$NBTABS]=${DIRNAME[@]:$NBTABS}
	
	# Read the stack to compute the full directory path	
	DIRPATH='.'
	for (( i = 0 ; i <= $NBTABS ; i++ )); do DIRPATH="$DIRPATH/${STACK[$i]}"; done
	
	# Create the directory and its parent directories if necessary
	# echo Creating $DIRPATH
	mkdir -p $DIRPATH	
done

# Restore the old delimiter
IFS=$OLDIFS
